@@ -23,6 +23,7 @@ enum {
   PHOSH_MONITOR_PROP_0,
   PHOSH_MONITOR_PROP_WL_OUTPUT,
   PHOSH_MONITOR_PROP_POWER_MODE,
+  PHOSH_MONITOR_PROP_N_GAMMA_ENTRIES,
   PHOSH_MONITOR_PROP_LAST_PROP,
 };
 static GParamSpec *props[PHOSH_MONITOR_PROP_LAST_PROP];
@@ -277,6 +278,7 @@ handle_wl_gamma_size (void *data, struct zwlr_gamma_control_v1 *gamma_control, u
   PhoshMonitor *self = PHOSH_MONITOR (data);
 
   self->n_gamma_entries = size;
+  g_object_notify_by_pspec (G_OBJECT (self), props[PHOSH_MONITOR_PROP_N_GAMMA_ENTRIES]);
 }
 
 
@@ -332,6 +334,9 @@ phosh_monitor_get_property (GObject *object,
   case PHOSH_MONITOR_PROP_POWER_MODE:
     g_value_set_enum (value, self->power_mode);
     break;
+  case PHOSH_MONITOR_PROP_N_GAMMA_ENTRIES:
+    g_value_set_uint (value, self->n_gamma_entries);
+    break;
   default:
     G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
     break;
@@ -429,6 +434,13 @@ phosh_monitor_class_init (PhoshMonitorClass *klass)
                        PHOSH_MONITOR_POWER_SAVE_MODE_OFF,
                        G_PARAM_READABLE |
                        G_PARAM_STATIC_STRINGS);
+  props[PHOSH_MONITOR_PROP_N_GAMMA_ENTRIES] =
+    g_param_spec_uint ("n-gamma-entries",
+                       "n-gamma-entries",
+                       "The number of gamma entries for this monitor",
+                       0, G_MAXUINT32, 0,
+                       G_PARAM_READABLE |
+                       G_PARAM_STATIC_STRINGS);
   g_object_class_install_properties (object_class, PHOSH_MONITOR_PROP_LAST_PROP, props);
 
   /**
@@ -527,6 +539,19 @@ phosh_monitor_is_flipped (PhoshMonitor *self)
 }
 
 
+/**
+ * phosh_monitor_has_gamma:
+ * @self: A #PhoshMonitor
+ *
+ * Returns: %TRUE if the monitor can modify gamma
+ */
+gboolean
+phosh_monitor_has_gamma (PhoshMonitor *self)
+{
+  return self->gamma_control && (self->n_gamma_entries > 0);
+}
+
+
 /**
  * phosh_monitor_get_transform:
  * @self: A #PhoshMonitor
@@ -691,3 +716,32 @@ phosh_monitor_get_fractional_scale (PhoshMonitor *self)
   }
   return mode->width / width;
 }
+
+
+/**
+ * phosh_monitor_transform_is_tilted:
+ * @transform: a #PhoshMonitorTransform
+ *
+ * We consider a transform to tilt the display if it changes the
+ * display orientation from portrait to landscape or vice versa.
+ *
+ * Returns: %TRUE for tilted transforms, otherwise %FALSE
+ */
+gboolean
+phosh_monitor_transform_is_tilted (PhoshMonitorTransform transform)
+{
+  switch (transform) {
+  case PHOSH_MONITOR_TRANSFORM_NORMAL:
+  case PHOSH_MONITOR_TRANSFORM_180:
+  case PHOSH_MONITOR_TRANSFORM_FLIPPED:
+  case PHOSH_MONITOR_TRANSFORM_FLIPPED_180:
+    return FALSE;
+  case PHOSH_MONITOR_TRANSFORM_90:
+  case PHOSH_MONITOR_TRANSFORM_270:
+  case PHOSH_MONITOR_TRANSFORM_FLIPPED_90:
+  case PHOSH_MONITOR_TRANSFORM_FLIPPED_270:
+    return TRUE;
+  default:
+    g_return_val_if_reached (FALSE);
+  }
+}
